function to = fft_bidirect(from, direction)
%FFT_BIDIRECT Fourier/inverse Fourier transform calculation.
%   FFT_BIDIRECT(FROM,DIRECTION) calculates the Fourier/ inverse Fourier 
%   transform of the imageScan channel FROM. If DIRECTION < 0, then the
%   transform is from the spatial to the frequency doamin, else it is the  
%   other way around. The transform is normalized by dividing by the number  
%   of elements in the input channel image (space->frequency, for the other 
%   direction it is multiplied).

% Check input
try
    parser = inputParser;
    parser.addRequired('from', @(from)is_channel(from) && ...
        strcmp(from.type,'imageScan'));
    parser.addOptional('direction', -1, @(direction) direction == 1 || ...
        direction == -1);
    parser.parse(from, direction);
catch error
    me = MException('spm:fft_bidirect:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

if (direction <= 0 && strcmp(from.pixel_domain,'frequency')) || ...
        (direction > 0 && strcmp(from.pixel_domain,'spatial'))
    me = MException('spm:fft_bidirect:domain_direction_mismatch', ...
        'Contradicting pixel domain and transformation direction');
    throw(me);
end

% Do the transformation
if direction <= 0
    work_image = fft2(from.pixels);
    if numel(work_image) ~= 0
        work_image = work_image / numel(work_image);
    end
else
    work_image = real(ifft2(from.pixels) * numel(from.pixels));
end

% Construct output structure and attache image
to = from;
to.pixels = work_image;

% Set pixel domain
if direction < 0
    to.pixel_domain = 'frequency';
else
    to.pixel_domain = 'spatial';
end

% Set pixel type
if ~isreal(to.pixels)
    to.pixel_type = 'complex';
end

end

