function to = fft_phase(from)
%FFT_PHASE Fourier transform phase.
%   FFT_PHASE(FROM) returns the phase of the Fourier transform of the 
%   spatial imageScan channel FROM

% Check input
try
    parser = inputParser;
    parser.addRequired('from', @(from)is_channel(from) && ...
        strcmp(from.type,'imageScan') && ...
        strcmp(from.pixel_domain,'spatial'));
    parser.parse(from);
catch error
    me = MException('spm:fft_phase:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

% Compute Fourier transform phase
work_image = angle(fft2(from.pixels));

% Construct output channel
to = from;
to.pixels = work_image;
to.pixel_domain('frequency');
to.name = sprintf('FFT phase of %s', channel.name);
to.unit = 'rad';
to.display_unit = 'rad';
to.display_scale = 1;

end



