function str = call_string()
% CALL_STRING Returns a string containing the call string of the function,
% in which it is called. Code is inspired on: http://tinyurl.com/cgekysj

% Get call-stack info:
st_debug = dbstack;

if length(st_debug) >= 3
    % We know a-priori that this function's caller info is in (st_debug)(2)
    
    % Get caller file name & line number of code which called this function:
    caller_file_name = st_debug(3).file;
    caller_line_number = st_debug(3).line;
    
    % Open caller file:
    fcaller = fopen(caller_file_name);
    
    % Iterate through lines to get to desired line number:
    for iLine = 1 :caller_line_number
        
        % Read current line of text:
        str = fgetl(fcaller);
    end
    
    % Close caller file:
    fclose(fcaller);
    
else
    % Get session history from Java object:
    history_services = com.mathworks.mlservices.MLCommandHistoryServices;
    history =  history_services.getSessionHistory;
    
    % Convert to a vector of char strings:
    history_text = char(history);
    
    % Convert to a cell vector of strings:
    cv_history = cellstr(history_text);
    
    % Extract last string:
    str = cv_history{end};
end

end
