function result = cbesseli1(z) %#codegen
%CBESSELI1  1st order Bessel function of the first kind.
%   CBESSELI1(Z) returns the Bessel function I_1(Z) of the complex vector 
%   Z. The answer is a good approximation for -PI/2 < arg(Z) < PI/2. The 
%   algorithm can be found in Handbook of Mathematical Functions 
%   (eq. 9.8.3) or in numerical recipies, but must be adjusted for complex 
%   numbers.
%
%   The function can be tested using 'besstest'.

result = z; %Create an array for the result

larger = (abs(z) > 3.75); %array element becomes 1 when |z| > 3.75
wlarger = find(larger);
wsmaller = find(1 - larger);

% Calculate result of the first or the second approximation, depending
% on the magnitude of z:
if ~isempty(wsmaller)
    result(wsmaller) = z(wsmaller) .* polyval(...
        fliplr([0.5, 0.87890594, 0.51498869, 0.15084934, 0.02658733, ...
        0.00301532, 0.00032411]), (z(wsmaller) / 3.75).^2);
end
if ~isempty(wlarger)
    result(wlarger) = exp(z(wlarger)) ./ sqrt(z(wlarger)) .* ...
        polyval(fliplr([0.39894228, -0.03988024, -0.00362018, ...
        0.00163801, -0.01031555, 0.02282967, -0.02895312, 0.01787654, ...
        -0.00420059]), 3.75./z(wlarger));
end

end