function dxdy = compute_dxdy(channel, direction) 
%COMPUTE_DXDY Neighbouring pixel distance computation.
%   COMPUTE_DXDY(channel, direction) returns the distance between two 
%   neighboring points in the spatial imageScan channel CHANNEL in x or y 
%   direction in meters. DIRECTION = 1 denotes the  x-direction, 
%   DIRECTION = 2 denotes the y-direction. 

% Check input
try
    parser = inputParser;
    parser.addRequired('channel', @(channel)is_channel(channel) && ...
        strcmp(channel.type,'imageScan') && ...
        ~isempty(channel.pixels));
    parser.addRequired('direction', @(direction)direction == 1 || ...
        direction == 2);
    parser.parse(channel, direction);
catch error
    me = MException('spm:compute_dxdy:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

% Get distance in channel display units
[hor_axis, vert_axis, ~, ~] = ...
    get_axes_and_params(channel);
if direction == 1
    if hor_axis.count == 0
    end
    dxdy =  hor_axis.variable.extent / ...
        hor_axis.count;
else %direction = 2
     if vert_axis.count == 0
    end
    dxdy = vert_axis.variable.extent / ...
        vert_axis.count;
end
        
end

