function [k, kx, ky] = generate_k_matrices(channel, dx, dy)
%GENERATE_K_MATRICES k-Matrix generation (helper function).
%   [K, KX, KY] = GENERATE_K_MATRICES(CHANNEL, DX, DY) generates k-matrices 
%   for the 2D-channel CHANNEL. K is a matrix of the same size as the pixel 
%   matrix of CHANNEL, containing the real-life frequency distance of each 
%   pixel position to the nearest corner of an matrix that is one pixel
%   wider/higher. KX is of the same size as K and contains the real-life 
%   difference in x-direction of each pixel position to the nearest corner 
%   of a matrix that is one pixel wider/higher. Similarly, KY is of the 
%   same size as K,  containing the real-life difference in y-direction of 
%   each pixel position to the nearest corner of an matrix that is one 
%   pixel wider/higher.

% Get channel dimensions and inter-pixel distances
[nx, ny] = size(channel.pixels);
% dx = abs(channel.axis(1).variable.extent) / nx;
% dy = abs(channel.axis(2).variable.extent) / ny;

% Generate k, kx and k_y matrix
dkx = 2 * pi / (nx * dx);
dky = 2 * pi / (ny * dy);

ky = 0 : ny - 1;
ky = (mod(ky + ny / 2, ny) - ny/2) * dky;
ky = ky' * ones(1, nx);

kx = 0 : nx - 1;
kx = (mod(kx + nx / 2, nx) - nx/2) * dkx;
kx = ones(ny, 1) * kx;

k = dist_v2(nx, dkx, ny, dky);
k(1, 1) = 1.0;  % Prevent division by zero and illegal operand errors.
% This may be improved...

end

