function pixels = get_display_pixels(channel, options)
%GET_DISPLAY_PIXELS Helper function for spm_display to get display pixels
%   GET_DISPLAY_PIXELS(CHANNEL, OPTIONS) returns the pixels to be
%   displayed by spm_dispay given the channel CHANNEL and the display
%   options structure OPTIONS.

switch options.data_component
    case 'real'
        channel.pixels = real(channel.pixels);
    case 'imaginary'
        channel.pixels = imag(channel.pixels);
    case 'magnitude'
        channel.pixels = abs(channel.pixels);
    case 'log_magnitude'
        channel.pixels = 20 * log10(abs(channel.pixels) + eps(0));
    case 'phase'
        channel.pixels = angle(channel.pixels);
    otherwise
        me = MException(...
            'spm:get_display_pixels:unknown_data_component', ...
            'Unknown plot type.');
        throw(me);
end

switch options.mode
    case 'raw'
        pixels = channel.pixels;
    case 'global'
        switch options.order
            case 0
                valid = ~isnan(channel.pixels);
                pixels = channel.pixels - mean(channel.pixels(valid));
            case 1
                valid = ~isnan(channel.pixels);
                nof_rows = size(channel.pixels, 1);
                nof_columns = size(channel.pixels, 2);
                [column, row] = ...
                    meshgrid(1:nof_columns, 1:nof_rows);
                coefficients = ...
                    [column(valid), ...
                    row(valid), ...
                    ones(size(row(valid)))]\ ...
                    channel.pixels(valid);
                flattened = channel.pixels(:) - ...
                    [column(:), row(:), ones(size(row(:)))] * coefficients;
                pixels = reshape(flattened, nof_rows, nof_columns);
        end
    case 'line'
        switch options.order
            case 0
                pixels = zeros(size(channel.pixels));
                for i = 1:size(channel.pixels, 1)
                    valid = ~isnan(channel.pixels(i,:));
                    pixels(i, :) = channel.pixels(i, :) - ...
                        mean(channel.pixels(i, valid));
                end
            case 1
                pixels = zeros(size(channel.pixels));
                for i = 1:size(channel.pixels, 1)
                    valid = ~isnan(channel.pixels(i,:));
                    polynom = polyfit(find(valid), ...
                        channel.pixels(i, valid), 1);
                    pixels(i, :) = ...
                        channel.pixels(i, :) - ...
                        polyval(polynom, 1: size(pixels, 2));
                end
            otherwise
                me = MException(...
                    'spm:get_display_pixels:unknown_order_mode_option', ...
                    'Unknown combination of order and mode.');
                throw(me);
        end
end

if strcmp(channel.pixel_domain, 'frequency')
    pixels= fftshift(pixels);
end
pixels = imresize(pixels, options.scaling_factor, 'box');
        
        
end

