function [hor_unit, vert_unit, channel_unit] = get_display_units(...
    channel, data_component)
%GET_DISPLAY_UNITS Helper function for spm_display to get display units.
%    [hor_unit, vert_unit, channel_unit] = GET_DISPLAY_UNITS(CHANNEL, data_component)
%    returns display units of the independent and dependent variable(s) of
%    the channel CHANNEL given the plot type data_component. In case of a
%    1-dimensional channel the unit of the second independent variable is
%    set to the empty string.

[~, ~, hor_parameter, vert_parameter] = ...
        get_axes_and_params(channel);

if strcmp(channel.pixel_domain, 'spatial')
    hor_unit = hor_parameter.display_unit;
    if ~isempty(vert_parameter)
        vert_unit = vert_parameter.display_unit;
    else
        vert_unit = '';
    end
elseif strcmp(channel.pixel_domain, 'frequency')
        hor_unit = sprintf('1/%s',hor_parameter.display_unit);
    if ~isempty(vert_parameter)
        vert_unit = sprintf('1/%s',vert_parameter.display_unit);
    else
        vert_unit = '';
    end
else
    me = MException('spm:get_display_units:unknown_pixel_domain', ...
        'Unknown pixel space.');
    throw(me);
end

switch data_component
    case {'real','imaginary','magnitude'}
        channel_unit = channel.display_unit;
    case 'log_magnitude'
         channel_unit = sprintf('dB%s',channel.display_unit);
    case 'phase'
        channel_unit = 'rad';
    otherwise
        me = MException('spm:get_display_units:unknown_data_component', ...
            'Unknown plot type.');
        throw(me);
end

end

