function full_path = get_full_path(filename)
% GET_FULL_PATH Get full path of file
%   GET_FULL_PATH(FILENAME) returns the full path of the file FILENAME.

if verLessThan('matlab', '7.14')
    error(nargchk(1, 1, nargin));
else
    narginchk(1, 1);
end

if ~ischar(filename)
    me = MException('spm:get_full_path:invalid_input', ...
                               'First argument should be a string.');
    throw(me);
end

fid = fopen(filename);

if fid ~= -1
    full_path = fopen(fid);
    fclose(fid);
else
    [path, ~, ~] = fileparts(filename);
    dir_created = false;
    if ~exist(path, 'dir') && ~isempty(path)
        [success, ~, ~] = mkdir(path);
        if ~success
             me = MException('spm:get_full_path:invalid_directory', ...
                              ['Unable to create non-existing' , ...
                              ' directory %s'], path);
        throw(me);
        end
        dir_created = true;
    end
    fid = fopen(filename, 'a+');
    if fid ~= -1
        full_path = fopen(fid);
        fclose(fid);
    else
        me = MException('spm:get_full_path:invalid_path', ...
                               'Input %s is not a valid path.', filename);
        throw(me);
    end
    if dir_created
        rmdir(path, 's');
    else
        delete(filename);
    end
end

