function channel_flag = is_channel(object)
%ISCHANNEL Check if something is a channel.
%   ISCHANNEL(OBJECT) return true when OBJECT is a channel and false
%   otherwise.

% Check number of arguments
if verLessThan('matlab', '7.14')
    error(nargchk(1, 1, nargin)); %#ok<NCHKN>
else
    narginchk(1, 1);
end

% Check length
if length(object) > 1
    channel_flag = false;
    return;
end

% Convert to old-fashioned struct
id = 'MATLAB:structOnObject';
warning('off', id);
object = struct(object);
warning('on', id);

% Check if object is structure with pixels matrix and affine transform
% matrix of desired form (or no affine transform matrix at all)

    channel_flag = isstruct(object) && length(object) == 1 && ... 
        isfield(object, 'pixels') && isnumeric(object.pixels) && ...
        (~isfield(object, 'affine_transform') || ...
        (isnumeric(object.affine_transform) && ...
        (isempty(object.affine_transform) ||...
        isempty(find(size(object.affine_transform) ~= [3 3], 1)))));


if ~channel_flag
    return;
end

% Set pixels and affine transform matrix to empty string (already checked 
% above)
channel=object;
channel.pixels = '';
channel.affine_transform = '';
if isfield(channel,'control') && isempty(channel.control)
	 channel = rmfield(channel,'control');
end
channel_list.channel = channel;
pref.CellItem = false;
pref.StructItem = false;

% Convert structure to DOM tree
dom=xml_write([], channel_list, 'channel_list', pref);
cl_elements=dom.getElementsByTagName('channel_list');
cl_element=cl_elements.item(0);
cl_element.setAttribute('xmlns:xsi', ...
    'http://www.w3.org/2001/XMLSchema-instance');
cl_element.setAttribute('xsi:noNamespaceSchemaLocation', 'empa.xsd');

% Validate tree against EMPA schema
full_path = mfilename('fullpath');
root_path = fileparts(full_path);
empa_schema = fullfile(root_path, '..', 'xml', 'empa.xsd');
channel_flag = xml_validate(dom, empa_schema);

end

