function count_flag = is_count(object, varargin)
%IS_COUNT Check whether something represents the result of a count
%   IS_COUNT(OBJECT) returns true if OBJECT is the result of a count.
%   IS_COUNT(OBJECT,'zero_allowed', 'false') rejects zero as a valid count.
% Check input
try
    parser = inputParser;
    parser.addRequired('object',  @(object)true);
    parser.addParamValue('zero_allowed', true, @islogical);
    parser.parse(object, varargin{:})
catch error
    me = MException('spm:is_count:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

count_flag = (isscalar(object) && isnumeric(object) && ...
    floor(object) == object);

if ~parser.Results.zero_allowed
    count_flag = (count_flag && object ~= 0);
end

end

