function [width, height, y_shift] = space4colorbar(fig, tick_factor, label)
%SPACE4COLORBAR Colorbar space requirement measurement.
%   [WIDTH, HEIGHT, Y_SHIFT] = SPACE4COLORBAR(FIG, TICK_FACTOR, LABEL)
%   returns the width WIDTH and height HEIGHT, to which FIG should be set 
%   to incorporate a color bar with tick labels equal to 
%   TICK_FACTOR * standard ticks and ylabel LABEL. It also computed the 
%   required y-shift Y_SHIFT to be applied to the main axes to make 
%   everything fit inside the figure window. The function is intendedto be
%   a helper function for spm_display.

temp_fig = figure('Visible','off');
colormap('gray');
copyobj(get(fig,'children'),temp_fig);
fig_units = get(fig,'Units');
fig_pos = get(fig,'Position');
outside_screen_factor = 1.1;
fig_pos(1) = -outside_screen_factor * fig_pos(3);
fig_pos(2) = -outside_screen_factor * fig_pos(4);
set(temp_fig, 'Resize', 'off');
set(temp_fig, 'Units', fig_units);
set(temp_fig, 'Position', fig_pos);
set(temp_fig, 'Visible', 'on');
org_ax_units = get(gca,'Units');
set(gca,'Units','pixels');
org_pos = get(gca,'Position');
cbar = colorbar;
ylabel(cbar,label);
standard_ticks = get(cbar, 'YTick');
ticks = tick_factor * standard_ticks;
set(cbar, 'YTickLabel', ticks);
set(gca,'Position',org_pos);
set(gca, 'Units', org_ax_units);
drawnow;
c_label = ylabel(cbar,label);
org_clabel_units = get(c_label, 'Units');
set(c_label, 'Units', fig_units);
clabel_extent = get(c_label ,'Extent');
y_shift = max(-(clabel_extent(2) + org_pos(2)),0);
height = max(clabel_extent(4) + max((clabel_extent(2) + org_pos(2)),0), ...
    fig_pos(4));
set(c_label, 'Units',org_clabel_units);
outer_position = get(cbar,'OuterPosition');
width = (outer_position(1) + outer_position(3)) * fig_pos(3);
delete(temp_fig);

end

