function out = subtract_polynom(in, mask, order, mode)
%SUBTRACT_POLYNOM Helper function for spm_display and spm_flatten to substract
%a polynomial function from a matrix.
%   SUBTRACT_POLYNOM(IN, MASK, ORDER, 'global') considers the matrix IN as
%   a function of the index grid and subtracts the best fitting polynomial
%   of order ORDER using only those points that are labeled with ones in
%   the binary mask MASK to compute the fit. When calling 
%   SUBTRACT_POLYNOM(IN, MASK, ORDER, 'line'), the function operates on a
%   line-by-line basis.

% Fit and subtract polynom
nof_rows = size(in, 1);
nof_columns = size(in, 2);
switch mode
    case 'global'
        [column, row] = ...
            meshgrid(1:nof_columns, 1:nof_rows);
        selected = find(mask);
        if isempty(selected)
                me = MException('spm:subtract_polynom:undefined_fit', ...
                ['Unable to fit polynom of order  %d ', ...
                'to selected set of points.'], order);
                throw(me);
            end
        var_vals = zeros(length(selected), 2*order + 1);
        for i = 1:order
            var_vals(:,2*i - 1) = column(selected).^(order - i + 1);
            var_vals(:,2*i) = row(selected).^(order - i + 1);
        end
        var_vals(:, 2*order + 1) = ones(length(selected), 1);
        target = in(selected);
        target = target(:);
        coefficients = var_vals \ target;
        if ~isempty(find(isnan(coefficients), 1))
            me = MException('spm:subtract_polynom:undefined_fit', ...
                ['Unable to fit polynom of order  %d ', ...
                'to selected set of points.'], order);
            throw(me);
        end
        var_vals_full = zeros(nof_rows*nof_columns, 2*order + 1);
         for i = 1:order
            var_vals_full(:,2*i - 1) = column(:).^(order - i + 1);
            var_vals_full(:,2*i) = row(:).^(order - i + 1);
        end
        var_vals_full(:, 2*order + 1) = ones(nof_rows*nof_columns, 1);
        out = in(:) - var_vals_full * coefficients;
        out = reshape(out, nof_rows, nof_columns);
    case 'line'
        column = 1:nof_columns;
        out = in;
        for j = 1:nof_rows
            selected = find(mask(j,:))';
            if length(selected) < 2
                me = MException('spm:subtract_polynom:undefined_fit', ...
                ['Unable to fit polynom of order  %d ', ...
                'to selected set of points.'], order);
                throw(me);
            end
            var_vals = zeros(length(column(selected)), order + 1);
            for i = 1:order
                var_vals(:,i) = column(selected).^(order - i + 1);
            end
            var_vals(:,order + 1) = ones(length(selected), 1);
            target = in(j, selected);
            target = target(:);
            coefficients = var_vals \ target;
            var_vals_full = zeros(nof_columns, order + 1);
            for i = 1:order
                var_vals_full(:,i) = column.^(order - i + 1);
            end
            var_vals_full(:,order + 1) = ones(length(column), 1);
            out(j,:) = in(j,:) - (var_vals_full * coefficients)';
        end
end


end

