function out = periodic_filter(in, tukey_param)
%PERIODIC_FILTER Periodic filtering with interactive filter selection.
%   PERIODIC_FILTER(IN, TUKEY_PARAM) displays the result of Tukey windowing
%   IN with parameter TUKEY_PARAM and presents the user with a GUI to draw 
%   a filter mask in the frequency domain. After the user has pressed 
%   return or closed the mask selection window, the output of filtering the
%   displayed image with the selected filter is returned.

% Check input
try
    parser = inputParser;
    parser.addRequired('in', @(in)(is_channel(in)  && ...
        strcmp(in.type,'imageScan') && ...
        strcmp(in.pixel_domain,'spatial')));
    parser.addRequired('tukey_param', ...
        @(tukey_param) isnumeric(tukey_param) && ...
        numel(tukey_param) == 1 && tukey_param > 0);
    parser.parse(in, tukey_param);
catch error
    me = MException('spm:cut:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

% Construct display window name
if ~isempty(in.context)
    [~, name, ext] = fileparts(in.context{1}); 
    window_name = ['fft_', name, ext];
else
    window_name = 'fft';
end

% Apply Tukey window
tukey_windowed = fft_bidirect(tukey_window(in, tukey_param), -1);

% Show result of windowing
spm_display(tukey_windowed, 'data_component', 'log_magnitude', ...
    'window_name', window_name); 

% Let user build filter mask
mask = mask_builder(window_name);

% Filter Tukey windowed input with filter mask
out = fft_bidirect(apply_mask(tukey_windowed,mask),1);

end

