function [channels_out, indices] = replace_nan(channels_in)
%REPLACE_NAN Not-a-number replacement
%   [CHANNELS_OUT, INDICES] = REPLACE_NAN(CHANNELS_IN) replaces all the 
%   NaN pixels in the channels in the array CHANNELS_IN with the average
%   value of the pixel matrix (or with 0, if all the values are NaN). The 
%   result of the placement is written to CHANNELS_OUT. The indices of the 
%   channels where changes were applied are stored in INDICES.

% Check input
try
    parser = inputParser;
    parser.addRequired('filename', @is_channel_array);
catch error
    me = MException('spm:replaceNaN:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

channels_out = channels_in;
changed = zeros(length(channels_in), 1);
for k = 1:length(channels_in)
    nan = isnan(channels_in(k).pixels);
    if ~isempty(find(nan,1))
        changed(k) = 1;
        if isempty(~find(nan,1))
            average = 0;
        else
            average = mean(channels_in(k).pixels(~nan));
        end
        channels_out(k).pixels(nan) = average;
    end
end
indices = find(changed);


end

