function stats = spm_stats(channel,varargin)
%SPM_STATS Computation of some simple channel pixel statistics.
%   SPM_STATS(CHANNEL) returns a structure containing the maximum, 
%   minimum, mean, standard deviation and variance of the pixel data.
%   To select only one of these call SPM_STATS(CHANNEL, 'minimum'),
%   SPM_STATS(CHANNEL, 'maximum'), SPM_STATS(CHANNEL, 'mean'), 
%   SPM_STATS(CHANNEL, 'std') or SPM_STATS(CHANNEL, 'var').

% Check input
try
    parser = inputParser;
    parser.addRequired('in', @is_channel);
    parser.addOptional('stat', '', @(stat) (ischar(stat) && ...
        ismember(stat,{'','minimum', 'maximum', 'mean', 'std', 'var'})));
    parser.parse(channel,varargin{:});
    stat = parser.Results.stat;
catch error
    me = MException('spm:spm_stats:input_error', ...
        'Invalid input: %s', error.message);
    throw(me);
end

% Calculate pixel statistics
stats.minimum = min(channel.pixels(:));
stats.maximum = max(channel.pixels(:));
stats.mean = mean(channel.pixels(:));
stats.std = std(channel.pixels(:));
stats.var = var(channel.pixels(:));

if ~isempty(stat)
    stats= stats.(stat);
end

end

