<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2005/xpath-functions"
	xmlns:foo="http://whatever" exclude-result-prefixes="foo fn">
	<!-- output formatting -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8"
		indent="yes" />
	<xsl:strip-space elements="*" />
	<!-- conversion function -->
	<xsl:function name="foo:convert">
		<xsl:param name="org" />
		<xsl:param name="exp" />
		<xsl:param name="sign" />
		<xsl:choose>
			<xsl:when test="$org='NaN'">
				<xsl:copy-of select="$org" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="name" select="name($org)" />
				<xsl:element name="{$name}">
					<!-- <xsl:value-of select="fn:concat($org,fn:concat('E-',$exp))" /> -->
					<!-- <xsl:value-of select="$org * number(fn:concat('1E-',$exp))" /> -->
					<xsl:value-of
						select="$org * number(fn:concat(fn:concat('1E',$sign),$exp))" />
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:template match="channel_list">
		<channel_list xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
			xsi:noNamespaceSchemaLocation="empa.xsd">
			<!-- <channel_list xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"> -->
			<xsl:apply-templates />
		</channel_list>
	</xsl:template>
	<xsl:template match="channel_list/channel">
		<xsl:variable name="unit_list"
			select="'millimeter,millimeters,mm,microns,micron,um,µm,nm,nanometer,nanometers,nanometre,angstroem,angstroems,angstrom,angstroms'">
		</xsl:variable>
		<xsl:variable name="exp_list" select="'3,3,3,6,6,6,6,9,9,9,9,12,12,12,12'">
		</xsl:variable>
		<channel>
			<xsl:copy-of select="name" />
			<xsl:copy-of select="unit" />
			<xsl:copy-of select="display_unit" />
			<xsl:copy-of select="display_scale" />
			<xsl:copy-of select="type" />
			<xsl:copy-of select="context" />
			<xsl:copy-of select="ref_index" />
			<xsl:copy-of select="affine_transform" />
			<xsl:copy-of select="comment" />
			<xsl:copy-of select="session" />
			<xsl:copy-of select="date_time" />
			<xsl:copy-of select="control" />
			<xsl:variable name="conversion_indices">
				<xsl:for-each select="parameter">
					<xsl:variable name="unit" select="unit" />
					<xsl:if test="exists(tokenize($unit_list, ',')[. = $unit])">
						<xsl:value-of select="position()" />
						<xsl:text>,</xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<xsl:variable name="param_exps">
				<xsl:for-each select="parameter">
					<xsl:variable name="unit" select="unit" />
					<xsl:choose>
						<xsl:when test="exists(tokenize($unit_list, ',')[. = $unit])">
							<xsl:variable name="index"
								select="fn:index-of(tokenize($unit_list, ','), $unit)" />
							<xsl:value-of select="tokenize($exp_list, ',')[$index]" />
							<xsl:text>,</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>0,</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:variable>
			<xsl:for-each select="parameter">
				<xsl:variable name="parameter_position" select="position()" />
				<parameter>
					<xsl:copy-of select="name" />
					<xsl:variable name="unit" select="unit" />
					<xsl:choose>
						<xsl:when
							test="not(exists(tokenize($conversion_indices, ',')[. = string($parameter_position)]))">
							<xsl:copy-of select="start_value" />
							<xsl:copy-of select="drift" />
							<xsl:copy-of select="shift" />
							<xsl:copy-of select="unit" />
							<xsl:copy-of select="display_unit" />
							<xsl:copy-of select="display_scale" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="exp"
								select="tokenize($param_exps, ',')[$parameter_position]" />
							<start_value>
								<xsl:copy-of select="foo:convert(start_value/coarse, $exp, '-')" />
								<xsl:copy-of select="foo:convert(start_value/fine, $exp, '-')" />
								<xsl:copy-of select="foo:convert(start_value/real, $exp, '-')" />
							</start_value>
							<xsl:copy-of select="foo:convert(drift, $exp, '-')" />
							<xsl:copy-of select="foo:convert(shift, $exp, '-')" />
							<unit>m</unit>
							<xsl:copy-of select="display_unit" />
							<xsl:copy-of select="foo:convert(display_scale, $exp, '+')" />
						</xsl:otherwise>
					</xsl:choose>
				</parameter>
			</xsl:for-each>
			<xsl:for-each select="axis">
				<axis>
					<xsl:copy-of select="name" />
					<xsl:copy-of select="count" />
					<xsl:copy-of select="direction" />
					<xsl:copy-of select="interval" />
					<xsl:for-each select="variable">
						<xsl:variable name="ref_index" select="ref_index" />
						<xsl:variable name="exp_ref"
							select="tokenize($param_exps, ',')[fn:number($ref_index)]" />
						<variable>
							<xsl:copy-of select="$ref_index" />
							<xsl:copy-of select="foo:convert(extent, $exp_ref, '-')" />
						</variable>
					</xsl:for-each>
				</axis>
			</xsl:for-each>
			<xsl:copy-of select="pixel_domain" />
			<xsl:copy-of select="pixel_type" />
			<xsl:copy-of select="pixels" />
		</channel>
	</xsl:template>
</xsl:stylesheet>